export declare enum AccountFlags {
    none = 0,
    linked = 1,
    debits_must_not_exceed_credits = 2,
    credits_must_not_exceed_debits = 4,
    history = 8
}
export declare enum TransferFlags {
    none = 0,
    linked = 1,
    pending = 2,
    post_pending_transfer = 4,
    void_pending_transfer = 8,
    balancing_debit = 16,
    balancing_credit = 32
}
export declare enum AccountFilterFlags {
    none = 0,
    debits = 1,
    credits = 2,
    reversed = 4
}
export declare type Account = {
    id: bigint;
    debits_pending: bigint;
    debits_posted: bigint;
    credits_pending: bigint;
    credits_posted: bigint;
    user_data_128: bigint;
    user_data_64: bigint;
    user_data_32: number;
    reserved: number;
    ledger: number;
    code: number;
    flags: number;
    timestamp: bigint;
};
export declare type Transfer = {
    id: bigint;
    debit_account_id: bigint;
    credit_account_id: bigint;
    amount: bigint;
    pending_id: bigint;
    user_data_128: bigint;
    user_data_64: bigint;
    user_data_32: number;
    timeout: number;
    ledger: number;
    code: number;
    flags: number;
    timestamp: bigint;
};
export declare enum CreateAccountError {
    ok = 0,
    linked_event_failed = 1,
    linked_event_chain_open = 2,
    timestamp_must_be_zero = 3,
    reserved_field = 4,
    reserved_flag = 5,
    id_must_not_be_zero = 6,
    id_must_not_be_int_max = 7,
    flags_are_mutually_exclusive = 8,
    debits_pending_must_be_zero = 9,
    debits_posted_must_be_zero = 10,
    credits_pending_must_be_zero = 11,
    credits_posted_must_be_zero = 12,
    ledger_must_not_be_zero = 13,
    code_must_not_be_zero = 14,
    exists_with_different_flags = 15,
    exists_with_different_user_data_128 = 16,
    exists_with_different_user_data_64 = 17,
    exists_with_different_user_data_32 = 18,
    exists_with_different_ledger = 19,
    exists_with_different_code = 20,
    exists = 21
}
export declare enum CreateTransferError {
    ok = 0,
    linked_event_failed = 1,
    linked_event_chain_open = 2,
    timestamp_must_be_zero = 3,
    reserved_flag = 4,
    id_must_not_be_zero = 5,
    id_must_not_be_int_max = 6,
    flags_are_mutually_exclusive = 7,
    debit_account_id_must_not_be_zero = 8,
    debit_account_id_must_not_be_int_max = 9,
    credit_account_id_must_not_be_zero = 10,
    credit_account_id_must_not_be_int_max = 11,
    accounts_must_be_different = 12,
    pending_id_must_be_zero = 13,
    pending_id_must_not_be_zero = 14,
    pending_id_must_not_be_int_max = 15,
    pending_id_must_be_different = 16,
    timeout_reserved_for_pending_transfer = 17,
    amount_must_not_be_zero = 18,
    ledger_must_not_be_zero = 19,
    code_must_not_be_zero = 20,
    debit_account_not_found = 21,
    credit_account_not_found = 22,
    accounts_must_have_the_same_ledger = 23,
    transfer_must_have_the_same_ledger_as_accounts = 24,
    pending_transfer_not_found = 25,
    pending_transfer_not_pending = 26,
    pending_transfer_has_different_debit_account_id = 27,
    pending_transfer_has_different_credit_account_id = 28,
    pending_transfer_has_different_ledger = 29,
    pending_transfer_has_different_code = 30,
    exceeds_pending_transfer_amount = 31,
    pending_transfer_has_different_amount = 32,
    pending_transfer_already_posted = 33,
    pending_transfer_already_voided = 34,
    pending_transfer_expired = 35,
    exists_with_different_flags = 36,
    exists_with_different_debit_account_id = 37,
    exists_with_different_credit_account_id = 38,
    exists_with_different_amount = 39,
    exists_with_different_pending_id = 40,
    exists_with_different_user_data_128 = 41,
    exists_with_different_user_data_64 = 42,
    exists_with_different_user_data_32 = 43,
    exists_with_different_timeout = 44,
    exists_with_different_code = 45,
    exists = 46,
    overflows_debits_pending = 47,
    overflows_credits_pending = 48,
    overflows_debits_posted = 49,
    overflows_credits_posted = 50,
    overflows_debits = 51,
    overflows_credits = 52,
    overflows_timeout = 53,
    exceeds_credits = 54,
    exceeds_debits = 55
}
export declare type CreateAccountsError = {
    index: number;
    result: CreateAccountError;
};
export declare type CreateTransfersError = {
    index: number;
    result: CreateTransferError;
};
export declare type AccountFilter = {
    account_id: bigint;
    timestamp_min: bigint;
    timestamp_max: bigint;
    limit: number;
    flags: number;
};
export declare type AccountBalance = {
    debits_pending: bigint;
    debits_posted: bigint;
    credits_pending: bigint;
    credits_posted: bigint;
    timestamp: bigint;
};
export declare enum Operation {
    pulse = 128,
    create_accounts = 129,
    create_transfers = 130,
    lookup_accounts = 131,
    lookup_transfers = 132,
    get_account_transfers = 133,
    get_account_balances = 134
}
